@@ -1,8 +1,8 @@
 #include "TaskData.h"
 
 #include <algorithm>
+#include <boost/regex.hpp>
 #include <meojson/json.hpp>
-#include <regex>
 
 #ifdef ASST_DEBUG
 #include <queue>
@@ -166,7 +166,8 @@ bool asst::TaskData::lazy_parse(const json::value& json)
                     return true;
                 };
             bool enable_justreturn_check = true;
-            if (name.ends_with("LoadingText") || name.ends_with("LoadingIcon")) {
+            if (name.ends_with("LoadingText") || name.ends_with("LoadingTextPostDelay") ||
+                name.ends_with("LoadingIcon")) {
                 // 放宽对 Loading 类任务的限制，不然 JustReturn 的任务如果本身有 JR 的 next，就不能 @Loading 了
                 enable_justreturn_check = false;
             }
@@ -191,9 +192,9 @@ bool asst::TaskData::lazy_parse(const json::value& json)
                 task->algorithm == AlgorithmType::OcrDetect) {
                 for (const auto& [regex, new_str] : ocr_task->replace_map) {
                     try {
-                        std::regex _(regex);
+                        boost::regex _(regex);
                     }
-                    catch (const std::regex_error& e) {
+                    catch (const boost::regex_error& e) {
                         Log.error("Task", name, "has invalid regex:", regex, ":", e.what());
                         validity = false;
                         break;
@@ -225,7 +226,7 @@ bool asst::TaskData::load(const std::filesystem::path& path)
     json::object merged;
 
     if (is_regular_file(path)) {
-        Log.debug("TaskData::load", "Loading json file:", path);
+        // Log.debug("TaskData::load", "Loading json file:", path);
         auto ret = json::open(path, true);
         if (!ret) {
             Log.error("TaskData::load", "Json open failed:", path);
@@ -241,7 +242,7 @@ bool asst::TaskData::load(const std::filesystem::path& path)
             }
         }
         for (const auto& file : json_files) {
-            Log.debug("TaskData::load", "Loading json file:", file);
+            // Log.debug("TaskData::load", "Loading json file:", file);
             auto ret = json::open(file, true);
             if (!ret) {
                 Log.error("TaskData::load", "Json open failed:", file);
