@@ -366,7 +366,7 @@ bool asst::BattleFormationTask::add_trust_operators()
     }
 
     // 需要追加的信赖干员数量
-    int append_count = 12 - (int)m_opers_in_formation->size();
+    int append_count = 12 + m_used_support_unit - (int)m_opers_in_formation->size();
     if (append_count == 0) {
         return true;
     }
@@ -787,7 +787,9 @@ std::optional<std::string> asst::BattleFormationTask::add_support_unit(
     LogTraceFunction;
 
     // 通过点击编队界面右上角 <助战单位> 文字左边的 Icon 进入助战干员选择界面
-    ProcessTask(*this, { "Formation-AddSupportUnit-EnterSupportList" }).run();
+    if (!ProcessTask(*this, { "Formation-AddSupportUnit-EnterSupportList" }).set_retry_times(20).run()) {
+        return std::nullopt;
+    }
 
     SupportList support_list(m_callback, m_inst, m_task_chain);
 
